Crate logic_tracer
source ·Expand description
Logic Tracer
logic_tracer is a library for tracing the logic of a logic propopsition.
Also creates a truth table and a Karnaugh map (if possible).
Features
- Creates a logic trace
- Creates a truth table
- Creates a Karnaugh map
- Reduces the logic proposition to its simplest form (if possible)
- Creates a circuit diagram (if possible)
- Serializes the logic proposition to a file (must be implemented)
Modules
- This module contains the lexer, which is responsible for the lexical analysis of the source code.
- This module provides the parser, which is responsible for syntactic and semantic analysis of the token stream produced by the lexer.
- This module defines the primitive token types that are recognized and used by the lexer and parser components.
Macros
- Macro to implement specific token types for a given trait.
- Macro to implement a token recognizer for a given set of token types.
- Macro to implement specific token types for a given trait. Implements the ‘from’ method for the token type to create a Box
from a string.